@@ -3,14 +3,10 @@ use IO::Socket;
 use IO::Select;
 use strict;
 
-sub make_socks_server {
+sub make_socks_server() {
 	my ($version, $login, $password, %delay) = @_;
 	
 	my $serv = IO::Socket::Socks->new(Listen => 3, SocksVersion => $version, RequireAuth => ($login && $password), UserAuth => sub {
-		$login = ''    unless defined $login;
-		$password = '' unless defined $password;
-		$_[0] = '' unless defined $_[0];
-		$_[1] = '' unless defined $_[1];
 		return $_[0] eq $login && $_[1] eq $password;
 	}) or die $@;
 	
@@ -22,16 +18,15 @@ sub make_socks_server {
 			if ($delay{accept}) {
 				sleep $delay{accept};
 			}
-			
 			my $client = $serv->accept()
 				or next;
-				
+			
 			my $subchild = fork();
 			die 'subfork: ', $! unless defined $subchild;
 			
 			if ($subchild == 0) {
 				my ($cmd, $host, $port) = @{$client->command()};
-
+				
 				if($cmd == CMD_CONNECT)
 				{ # connect
 					my $socket = IO::Socket::INET->new(PeerHost => $host, PeerPort => $port, Timeout => 10);
